Documentation
¶
Index ¶
- Constants
- func IsDependentObjectsError(err error) bool
- type DefaultScope
- type ElasticSearchCredentialsReconciler
- type ElasticSearchIndexTemplateReconciler
- type ElasticSearchUserReconciler
- type ElasticsearchILMPolicyReconciler
- type MySqlCredentialsReconciler
- type MySqlDatabaseReconciler
- type MySqlUserReconciler
- type NamespaceManagementReconciler
- type PostgresCredentialsReconciler
- type PostgresDatabaseReconciler
- type PostgresUserReconciler
- type Scope
Constants ¶
const ( ElasticSearchSecretProtectionFinalizerName = "projects.deployments.plural.sh/elastic-search-secret-protection" PostgresSecretProtectionFinalizerName = "projects.deployments.plural.sh/postgres-secret-protection" MySqlSecretProtectionFinalizerName = "projects.deployments.plural.sh/mysql-secret-protection" )
const (
ElasticSearchCredentialsProtectionFinalizerName = "projects.deployments.plural.sh/elastic-search-credentials-protection"
)
const (
ElasticSearchUserProtectionFinalizerName = "projects.deployments.plural.sh/elastic-search-user-protection"
)
const (
ElasticsearchIndexTemplateProtectionFinalizerName = "projects.deployments.plural.sh/elastic-search-template-protection"
)
const (
MySqlCredentialsProtectionFinalizerName = "projects.deployments.plural.sh/mysql-credentials-protection"
)
const (
MySqlDatabaseProtectionFinalizerName = "projects.deployments.plural.sh/mysql-database-protection"
)
const (
MySqlUserProtectionFinalizerName = "projects.deployments.plural.sh/mysql-user-protection"
)
const (
PolicyFinalizer = "deployments.plural.sh/ilmpolicy-protection"
)
const (
PostgresCredentialsProtectionFinalizerName = "projects.deployments.plural.sh/postgres-credentials-protection"
)
const (
PostgresDatabaseProtectionFinalizerName = "projects.deployments.plural.sh/postgres-database-protection"
)
const (
PostgresUserProtectionFinalizerName = "projects.deployments.plural.sh/postgres-user-protection"
)
Variables ¶
This section is empty.
Functions ¶
func IsDependentObjectsError ¶
IsDependentObjectsError checks if the error is a PostgreSQL "2BP01" error. 2BP01 = dependent_objects_still_exist
Types ¶
type DefaultScope ¶
func (*DefaultScope[T]) PatchObject ¶
func (in *DefaultScope[T]) PatchObject() error
type ElasticSearchCredentialsReconciler ¶
type ElasticSearchCredentialsReconciler struct {
client.Client
Scheme *runtime.Scheme
ElasticsearchClient elasticsearch.ElasticsearchClient
}
ElasticSearchCredentialsReconciler reconciles a ElasticsearchCredentials object
func (*ElasticSearchCredentialsReconciler) Reconcile ¶
func (r *ElasticSearchCredentialsReconciler) Reconcile(ctx context.Context, req ctrl.Request) (_ ctrl.Result, retErr error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.16.3/pkg/reconcile
func (*ElasticSearchCredentialsReconciler) SetupWithManager ¶
func (r *ElasticSearchCredentialsReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type ElasticSearchIndexTemplateReconciler ¶
type ElasticSearchIndexTemplateReconciler struct {
client.Client
Scheme *runtime.Scheme
ElasticsearchClient e.ElasticsearchClient
}
ElasticSearchIndexTemplateReconciler reconciles a ElasticsearchIndexTemplate object
func (*ElasticSearchIndexTemplateReconciler) Reconcile ¶
func (r *ElasticSearchIndexTemplateReconciler) Reconcile(ctx context.Context, req ctrl.Request) (_ ctrl.Result, retErr error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.16.3/pkg/reconcile
func (*ElasticSearchIndexTemplateReconciler) SetupWithManager ¶
func (r *ElasticSearchIndexTemplateReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type ElasticSearchUserReconciler ¶
type ElasticSearchUserReconciler struct {
client.Client
Scheme *runtime.Scheme
ElasticsearchClient e.ElasticsearchClient
}
ElasticSearchUserReconciler reconciles a ElasticsearchUser object
func (*ElasticSearchUserReconciler) Reconcile ¶
func (r *ElasticSearchUserReconciler) Reconcile(ctx context.Context, req ctrl.Request) (_ ctrl.Result, retErr error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.16.3/pkg/reconcile
func (*ElasticSearchUserReconciler) SetupWithManager ¶
func (r *ElasticSearchUserReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type ElasticsearchILMPolicyReconciler ¶
type ElasticsearchILMPolicyReconciler struct {
client.Client
Scheme *runtime.Scheme
ElasticsearchClient e.ElasticsearchClient
}
ElasticsearchILMPolicyReconciler reconciles an ElasticsearchILMPolicy object
func (*ElasticsearchILMPolicyReconciler) Reconcile ¶
func (r *ElasticsearchILMPolicyReconciler) Reconcile(ctx context.Context, req ctrl.Request) (_ ctrl.Result, retErr error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.16.3/pkg/reconcile
func (*ElasticsearchILMPolicyReconciler) SetupWithManager ¶
func (r *ElasticsearchILMPolicyReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type MySqlCredentialsReconciler ¶
type MySqlCredentialsReconciler struct {
client.Client
Scheme *runtime.Scheme
MySqlClient mysql.MySqlClient
}
MySqlCredentialsReconciler reconciles a MySqlCredentials object
func (*MySqlCredentialsReconciler) Reconcile ¶
func (r *MySqlCredentialsReconciler) Reconcile(ctx context.Context, req ctrl.Request) (_ ctrl.Result, retErr error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.16.3/pkg/reconcile
func (*MySqlCredentialsReconciler) SetupWithManager ¶
func (r *MySqlCredentialsReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type MySqlDatabaseReconciler ¶
type MySqlDatabaseReconciler struct {
client.Client
Scheme *runtime.Scheme
MySqlClient mysql.MySqlClient
}
MySqlDatabaseReconciler reconciles a MySqlDatabase object
func (*MySqlDatabaseReconciler) Reconcile ¶
func (r *MySqlDatabaseReconciler) Reconcile(ctx context.Context, req ctrl.Request) (_ ctrl.Result, retErr error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.16.3/pkg/reconcile
func (*MySqlDatabaseReconciler) SetupWithManager ¶
func (r *MySqlDatabaseReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type MySqlUserReconciler ¶
type MySqlUserReconciler struct {
client.Client
Scheme *runtime.Scheme
MySqlClient mysql.MySqlClient
}
MySqlUserReconciler reconciles a MySqlUser object
func (*MySqlUserReconciler) Reconcile ¶
func (r *MySqlUserReconciler) Reconcile(ctx context.Context, req ctrl.Request) (_ ctrl.Result, retErr error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.16.3/pkg/reconcile
func (*MySqlUserReconciler) SetupWithManager ¶
func (r *MySqlUserReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type NamespaceManagementReconciler ¶
type NamespaceManagementReconciler struct {
client.Client
Scheme *runtime.Scheme
MaxNamespaceAge time.Duration
}
NamespaceManagementReconciler reconciles a NamespaceManagement object
func (*NamespaceManagementReconciler) Reconcile ¶
func (r *NamespaceManagementReconciler) Reconcile(ctx context.Context, req ctrl.Request) (result ctrl.Result, retErr error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.21.0/pkg/reconcile
func (*NamespaceManagementReconciler) SetupWithManager ¶
func (r *NamespaceManagementReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type PostgresCredentialsReconciler ¶
type PostgresCredentialsReconciler struct {
client.Client
Scheme *runtime.Scheme
PostgresClient postgres.Client
}
PostgresCredentialsReconciler reconciles a PostgresCredentials object
func (*PostgresCredentialsReconciler) Reconcile ¶
func (r *PostgresCredentialsReconciler) Reconcile(ctx context.Context, req ctrl.Request) (_ ctrl.Result, retErr error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.16.3/pkg/reconcile
func (*PostgresCredentialsReconciler) SetupWithManager ¶
func (r *PostgresCredentialsReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type PostgresDatabaseReconciler ¶
type PostgresDatabaseReconciler struct {
client.Client
Scheme *runtime.Scheme
PostgresClient postgres.Client
}
PostgresDatabaseReconciler reconciles a PostgresDatabase object
func (*PostgresDatabaseReconciler) Reconcile ¶
func (r *PostgresDatabaseReconciler) Reconcile(ctx context.Context, req ctrl.Request) (_ ctrl.Result, retErr error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.16.3/pkg/reconcile
func (*PostgresDatabaseReconciler) SetupWithManager ¶
func (r *PostgresDatabaseReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type PostgresUserReconciler ¶
type PostgresUserReconciler struct {
client.Client
Scheme *runtime.Scheme
PostgresClient postgres.Client
}
PostgresUserReconciler reconciles a PostgresUser object
func (*PostgresUserReconciler) Reconcile ¶
func (r *PostgresUserReconciler) Reconcile(ctx context.Context, req ctrl.Request) (_ ctrl.Result, retErr error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.16.3/pkg/reconcile
func (*PostgresUserReconciler) SetupWithManager ¶
func (r *PostgresUserReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
Source Files
¶
- common.go
- elasticsearchcredentials_controller.go
- elasticsearchilmpolicy_controller.go
- elasticsearchindextemplate_controller.go
- elasticsearchuser_controller.go
- mysqlcredentials_controller.go
- mysqldatabase_controller.go
- mysqluser_controller.go
- namespacemanagement_controller.go
- postgrescredentials_controller.go
- postgresdatabase_controller.go
- postgresuser_controller.go
- scope.go